@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator;
 BEGIN {
-  $DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::VERSION = '0.001000_11';
+  $DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::VERSION = '0.001000_12';
 }
 use Moose;
 
@@ -8,11 +8,11 @@ use Moose;
 
 use autodie;
 use Carp qw( carp croak );
-use Log::Contextual::WarnLogger;
-use Log::Contextual qw(:log :dlog), -default_logger => Log::Contextual::WarnLogger->new({
-   env_prefix => 'DBICDH'
-});
-use Data::Dumper::Concise;
+use DBIx::Class::DeploymentHandler::Logger;
+use Log::Contextual qw(:log :dlog), -default_logger =>
+  DBIx::Class::DeploymentHandler::Logger->new({
+    env_prefix => 'DBICDH'
+  });
 
 use Method::Signatures::Simple;
 use Try::Tiny;
@@ -173,16 +173,15 @@ method _run_sql_array($sql) {
     join '', grep { !/^--/ } split /\n/ # remove comments
   } @$sql];
 
-  log_trace { '[DBICDH] Running SQL ' . Dumper($sql) };
+  Dlog_trace { "[DBICDH] Running SQL $_" } $sql;
   foreach my $line (@{$sql}) {
     $storage->_query_start($line);
+    # the whole reason we do this is so that we can see the line that was run
     try {
-      # do a dbh_do cycle here, as we need some error checking in
-      # place (even though we will ignore errors)
       $storage->dbh_do (sub { $_[1]->do($line) });
     }
     catch {
-      carp "$_ (running '${line}')"
+      die "$_ (running line '$line')"
     }
     $storage->_query_end($line);
   }
@@ -201,7 +200,7 @@ method _run_perl($filename) {
   no warnings 'redefine';
   my $fn = eval "$filedata";
   use warnings;
-  log_trace { '[DBICDH] Running Perl ' . Dumper($fn) };
+  Dlog_trace { "[DBICDH] Running Perl $_" } $fn;
 
   if ($@) {
     carp "$filename failed to compile: $@";
@@ -526,7 +525,7 @@ method _default_read_sql_file_as_string($file) {
 sub downgrade_single_step {
   my $self = shift;
   my $version_set = (shift @_)->{version_set};
-  log_info { qq([DBICDH] downgrade_single_step'ing ) . Dumper($version_set) };
+  Dlog_info { qq([DBICDH] downgrade_single_step'ing $_) } $version_set;
 
   my $sql = $self->_run_sql_and_perl($self->_ddl_schema_down_consume_filenames(
     $self->storage->sqlt_type,
@@ -539,7 +538,7 @@ sub downgrade_single_step {
 sub upgrade_single_step {
   my $self = shift;
   my $version_set = (shift @_)->{version_set};
-  log_info { qq([DBICDH] upgrade_single_step'ing ) . Dumper($version_set) };
+  Dlog_info { qq([DBICDH] upgrade_single_step'ing $_) } $version_set;
 
   my $sql = $self->_run_sql_and_perl($self->_ddl_schema_up_consume_filenames(
     $self->storage->sqlt_type,
